==> soma-base-4.5.4.tar.gz: soma-base-4.5.4/python/soma/somatime.py <==
# -*- coding: iso-8859-1 -*-

#  This software and supporting documentation are distributed by
#      Institut Federatif de Recherche 49
#      CEA/NeuroSpin, Batiment 145,
#      91191 Gif-sur-Yvette cedex
#      France
#
# This software is governed by the CeCILL-B license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/or redistribute the software under the 
# terms of the CeCILL-B license as circulated by CEA, CNRS
# and INRIA at the following URL "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-B license and that you accept its terms.

'''
Utility classes and functions for time handling.

@author: Yann Cointepas
@organization: U{NeuroSpin<http://www.neurospin.org>} and U{IFR 49<http://www.ifr49.org>}
@license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
'''
__docformat__ = "epytext en"

from soma.translation import translate as _

#----------------------------------------------------------------------------
def timeDifferenceToString( difference ):
  days = int( difference / 86400 )
  difference -= days * 86400
  hours = int( difference / 3600 )
  difference -= hours * 3600
  minutes = int( difference / 60 )
  seconds = int( difference - minutes * 60 )
  result = ''
  if days:
    return( _( '%d days %d hours %d minutes %d seconds' ) % ( days, hours, minutes, seconds ) )
  if hours:
    return( _( '%d hours %d minutes %d seconds' ) % ( hours, minutes, seconds ) )
  if minutes:
    return( _( '%d minutes %d seconds' ) % ( minutes, seconds ) )
  return( _( '%d seconds' ) % ( seconds, ) )

==> soma-base-4.5.6-3.tar.gz: soma-base-4.5.6/python/soma/somatime.py <==
# -*- coding: iso-8859-1 -*-

#  This software and supporting documentation are distributed by
#      Institut Federatif de Recherche 49
#      CEA/NeuroSpin, Batiment 145,
#      91191 Gif-sur-Yvette cedex
#      France
#
# This software is governed by the CeCILL-B license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/or redistribute the software under the
# terms of the CeCILL-B license as circulated by CEA, CNRS
# and INRIA at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-B license and that you accept its terms.

'''
Utility classes and functions for time handling.

* author: Yann Cointepas
* organization: NeuroSpin (http://www.neurospin.org)
* license: CeCILL B (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html)
'''
__docformat__ = "restructuredtext en"

from soma.translation import translate as _

#----------------------------------------------------------------------------


def timeDifferenceToString(difference):
    days = int(difference / 86400)
    difference -= days * 86400
    hours = int(difference / 3600)
    difference -= hours * 3600
    minutes = int(difference / 60)
    seconds = int(difference - minutes * 60)
    result = ''
    if days:
        return(_('%d days %d hours %d minutes %d seconds') % (days, hours, minutes, seconds))
    if hours:
        return(_('%d hours %d minutes %d seconds') % (hours, minutes, seconds))
    if minutes:
        return(_('%d minutes %d seconds') % (minutes, seconds))
    return(_('%d seconds') % (seconds, ))
